[fractal/fractal-next] Fix English in strings and comments



commit bae327b4a5872a212965d04236bba6e675106f51
Author: Alexandre Franke <alexandre franke gmail com>
Date:   Tue Jul 13 11:58:24 2021 +0000

    Fix English in strings and comments

 src/application.rs                              |  4 +--
 src/components/spinner_button.rs                |  2 +-
 src/secret.rs                                   |  8 +++---
 src/session/avatar.rs                           |  4 +--
 src/session/content/content.rs                  |  2 +-
 src/session/content/explore/explore.rs          |  2 +-
 src/session/content/explore/public_room.rs      |  2 +-
 src/session/content/explore/public_room_list.rs |  6 ++---
 src/session/content/invite.rs                   |  4 +--
 src/session/content/markdown_popover.rs         |  2 +-
 src/session/content/message_row.rs              |  4 +--
 src/session/content/room_history.rs             |  8 +++---
 src/session/content/state_row.rs                |  6 ++---
 src/session/mod.rs                              |  4 +--
 src/session/room/event.rs                       |  4 +--
 src/session/room/item.rs                        |  6 ++---
 src/session/room/room.rs                        | 34 ++++++++++++-------------
 src/session/room/room_type.rs                   |  2 +-
 src/session/room/timeline.rs                    | 16 ++++++------
 src/session/sidebar/sidebar.rs                  |  2 +-
 src/session/user.rs                             |  2 +-
 src/utils.rs                                    |  6 ++---
 22 files changed, 65 insertions(+), 65 deletions(-)
---
diff --git a/src/application.rs b/src/application.rs
index d7039ccb..0137f76d 100644
--- a/src/application.rs
+++ b/src/application.rs
@@ -81,7 +81,7 @@ impl Application {
             ("application-id", &Some(config::APP_ID)),
             ("flags", &ApplicationFlags::default()),
         ])
-        .expect("Application initialization failed...")
+        .expect("Application initialization failed")
     }
 
     fn get_main_window(&self) -> Window {
@@ -150,7 +150,7 @@ impl Application {
             .version(config::VERSION)
             .transient_for(&self.get_main_window())
             .modal(true)
-            .comments(gettext("A Matrix.org client for GNOME").as_str())
+            .comments(gettext("A Matrix client for GNOME").as_str())
             .copyright(gettext("© 2017-2021 The Fractal Team").as_str())
             .authors(vec![
                 "Alejandro Domínguez".to_string(),
diff --git a/src/components/spinner_button.rs b/src/components/spinner_button.rs
index edf0b387..a77687a4 100644
--- a/src/components/spinner_button.rs
+++ b/src/components/spinner_button.rs
@@ -49,7 +49,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "loading",
                         "Loading",
-                        "Wheter to display the loading spinner or the content",
+                        "Whether to display the loading spinner or the content",
                         false,
                         glib::ParamFlags::READWRITE | glib::ParamFlags::EXPLICIT_NOTIFY,
                     ),
diff --git a/src/secret.rs b/src/secret.rs
index cb6257f2..5e64b24a 100644
--- a/src/secret.rs
+++ b/src/secret.rs
@@ -15,7 +15,7 @@ pub struct StoredSession {
     pub device_id: DeviceIdBox,
 }
 
-/// Retrives all sessions stored to the `SecretService`
+/// Retrieves all sessions stored to the `SecretService`
 pub fn restore_sessions() -> Result<Vec<StoredSession>, secret_service::Error> {
     let ss = SecretService::new(EncryptionType::Dh)?;
     let collection = ss.get_default_collection()?;
@@ -75,13 +75,13 @@ pub fn restore_sessions() -> Result<Vec<StoredSession>, secret_service::Error> {
     Ok(res)
 }
 
-/// Writes a sessions to the `SecretService`, overwriting any previously stored session with the
+/// Writes a session to the `SecretService`, overwriting any previously stored session with the
 /// same `homeserver`, `username` and `device-id`.
 pub fn store_session(session: StoredSession) -> Result<(), secret_service::Error> {
     let ss = SecretService::new(EncryptionType::Dh)?;
     let collection = ss.get_default_collection()?;
 
-    // Store the infromation for the login
+    // Store the information for the login
     let attributes: HashMap<&str, &str> = [
         ("user-id", session.user_id.as_str()),
         ("homeserver", session.homeserver.as_str()),
@@ -99,7 +99,7 @@ pub fn store_session(session: StoredSession) -> Result<(), secret_service::Error
         "text/plain",
     )?;
 
-    // Store the infromation for the crypto store
+    // Store the information for the crypto store
     let attributes: HashMap<&str, &str> = [
         ("path", session.path.to_str().unwrap()),
         ("user-id", session.user_id.as_str()),
diff --git a/src/session/avatar.rs b/src/session/avatar.rs
index d645fe7c..c864f7d9 100644
--- a/src/session/avatar.rs
+++ b/src/session/avatar.rs
@@ -45,7 +45,7 @@ mod imp {
                     glib::ParamSpec::new_object(
                         "needed",
                         "Needed",
-                        "Whether the user defnied image should be loaded or it's not needed",
+                        "Whether the user defined image needs to be loaded",
                         gdk::Paintable::static_type(),
                         glib::ParamFlags::READWRITE | glib::ParamFlags::EXPLICIT_NOTIFY,
                     ),
@@ -170,7 +170,7 @@ impl Avatar {
                     // FIXME: We should retry if the request failed
                     match result {
                         Ok(data) => obj.set_image_data(Some(data)),
-                        Err(error) => error!("Couldn't fetch avatar: {}", error),
+                        Err(error) => error!("Couldn’t fetch avatar: {}", error),
                     };
                 }),
             );
diff --git a/src/session/content/content.rs b/src/session/content/content.rs
index f2380d8a..61c84443 100644
--- a/src/session/content/content.rs
+++ b/src/session/content/content.rs
@@ -70,7 +70,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "compact",
                         "Compact",
-                        "Wheter a compact view is used or not",
+                        "Whether a compact view is used",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
diff --git a/src/session/content/explore/explore.rs b/src/session/content/explore/explore.rs
index 119514e3..f7b8e19e 100644
--- a/src/session/content/explore/explore.rs
+++ b/src/session/content/explore/explore.rs
@@ -64,7 +64,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "compact",
                         "Compact",
-                        "Wheter a compact view is used or not",
+                        "Whether a compact view is used",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
diff --git a/src/session/content/explore/public_room.rs b/src/session/content/explore/public_room.rs
index 7269442f..884307e1 100644
--- a/src/session/content/explore/public_room.rs
+++ b/src/session/content/explore/public_room.rs
@@ -40,7 +40,7 @@ mod imp {
                     glib::ParamSpec::new_object(
                         "room",
                         "Room",
-                        "The room, this is only set if the user is alerady a member",
+                        "The room, this is only set if the user is already a member",
                         Room::static_type(),
                         glib::ParamFlags::READABLE,
                     ),
diff --git a/src/session/content/explore/public_room_list.rs b/src/session/content/explore/public_room_list.rs
index 5885eabc..614acb58 100644
--- a/src/session/content/explore/public_room_list.rs
+++ b/src/session/content/explore/public_room_list.rs
@@ -57,21 +57,21 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "loading",
                         "Loading",
-                        "Whether a response is loaded or not",
+                        "Whether a response is loaded",
                         false,
                         glib::ParamFlags::READABLE,
                     ),
                     glib::ParamSpec::new_boolean(
                         "empty",
                         "Empty",
-                        "Whether matching rooms are found or not",
+                        "Whether any matching rooms are found",
                         false,
                         glib::ParamFlags::READABLE,
                     ),
                     glib::ParamSpec::new_boolean(
                         "complete",
                         "Complete",
-                        "Whether the every search result is loaded or not",
+                        "Whether all search results are loaded",
                         false,
                         glib::ParamFlags::READABLE,
                     ),
diff --git a/src/session/content/invite.rs b/src/session/content/invite.rs
index 14e490c5..64c7e00d 100644
--- a/src/session/content/invite.rs
+++ b/src/session/content/invite.rs
@@ -65,7 +65,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "compact",
                         "Compact",
-                        "Wheter a compact view is used or not",
+                        "Whether a compact view is used",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
@@ -165,7 +165,7 @@ impl Invite {
             }
         }
 
-        // FIXME: remove clousure when room changes
+        // FIXME: remove closure when room changes
         if let Some(ref room) = room {
             let handler_id = room.connect_notify_local(
                 Some("category"),
diff --git a/src/session/content/markdown_popover.rs b/src/session/content/markdown_popover.rs
index 0fae4a38..35b1261f 100644
--- a/src/session/content/markdown_popover.rs
+++ b/src/session/content/markdown_popover.rs
@@ -34,7 +34,7 @@ pub mod imp {
                 vec![glib::ParamSpec::new_boolean(
                     "markdown-enabled",
                     "Markdown enabled",
-                    "Whether or not to do markdown formatting when sending messages",
+                    "Whether outgoing messages should be interpreted as markdown",
                     false,
                     glib::ParamFlags::READWRITE,
                 )]
diff --git a/src/session/content/message_row.rs b/src/session/content/message_row.rs
index e7638c2c..c1fc0d60 100644
--- a/src/session/content/message_row.rs
+++ b/src/session/content/message_row.rs
@@ -65,7 +65,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "show-header",
                         "Show Header",
-                        "Whether this item should show a header or not. This does do nothing if this event 
doesn't have a header. ",
+                        "Whether this item should show a header. This does nothing if this event doesn’t 
have a header. ",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
@@ -224,7 +224,7 @@ impl MessageRow {
                     AnyMessageEventContent::RoomRedaction(RedactionEventContent::new())
                 }
             }
-            _ => panic!("This event isn't a room message event or redacted event"),
+            _ => panic!("This event isn’t a room message event or redacted event"),
         }
     }
 
diff --git a/src/session/content/room_history.rs b/src/session/content/room_history.rs
index 498c4118..212a1274 100644
--- a/src/session/content/room_history.rs
+++ b/src/session/content/room_history.rs
@@ -77,7 +77,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "compact",
                         "Compact",
-                        "Wheter a compact view is used or not",
+                        "Whether a compact view is used",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
@@ -98,7 +98,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "markdown-enabled",
                         "Markdown enabled",
-                        "Whether or not to do markdown formatting when sending messages",
+                        "Whether outgoing messages should be interpreted as markdown",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
@@ -318,8 +318,8 @@ impl RoomHistory {
     }
 
     fn load_more_messages(&self, adj: &gtk::Adjustment) {
-        // Load more message when the user gets close to the end of the known room history
-        // Use the page size twice to detect if the user gets close the end
+        // Load more messages when the user gets close to the end of the known room history
+        // Use the page size twice to detect if the user gets close to the end
         if adj.value() < adj.page_size() * 2.0 || adj.upper() <= adj.page_size() * 2.0 {
             if let Some(room) = self.room() {
                 room.load_previous_events();
diff --git a/src/session/content/state_row.rs b/src/session/content/state_row.rs
index 349c7108..4dd0f6c9 100644
--- a/src/session/content/state_row.rs
+++ b/src/session/content/state_row.rs
@@ -125,7 +125,7 @@ impl StateRow {
                                 if state.state_key() == state.sender() {
                                     Some(gettext!("{} rejected the invite.", display_name))
                                 } else {
-                                    Some(gettext!("{}'s invite was revoked'.", display_name))
+                                    Some(gettext!("{}’s invite was revoked'.", display_name))
                                 }
                             }
                             Some(AnyStateEventContent::RoomMember(prev))
@@ -140,7 +140,7 @@ impl StateRow {
                             if state.state_key() == state.sender() {
                                 gettext!("{} left the room.", display_name)
                             } else {
-                                gettext!("{} was kicked of the room.", display_name)
+                                gettext!("{} was kicked out of the room.", display_name)
                             }
                         })
                     }
@@ -160,7 +160,7 @@ impl StateRow {
             }
             AnyStateEventContent::RoomTombstone(event) => {
                 gettext!("The room was upgraded: {}", event.body)
-                // Todo: add button for new room with acction session.show_room::room_id
+                // Todo: add button for new room with action session.show_room::room_id
             }
             _ => {
                 warn!("Unsupported state event: {}", state.event_type());
diff --git a/src/session/mod.rs b/src/session/mod.rs
index 92c7c87e..73eb6847 100644
--- a/src/session/mod.rs
+++ b/src/session/mod.rs
@@ -347,7 +347,7 @@ impl Session {
                 .sync_with_callback(sync_settings, |response| {
                     let sender = sender.clone();
                     async move {
-                        // Using the event hanlder doesn't make a lot of sense for us since we want every 
room event
+                        // Using the event handler doesn't make a lot of sense for us since we want every 
room event
                         // Eventually we should contribute a better EventHandler interface so that it makes 
sense to use it.
                         send!(sender, response);
 
@@ -411,7 +411,7 @@ impl Session {
 
     /// Returns and consumes the `error` that was generated when the session failed to login,
     /// on a successful login this will be `None`.
-    /// Unfortunatly it's not possible to connect the Error direclty to the `prepared` signals.
+    /// Unfortunately it's not possible to connect the Error directly to the `prepared` signals.
     pub fn get_error(&self) -> Option<matrix_sdk::Error> {
         let priv_ = &imp::Session::from_instance(self);
         priv_.error.take()
diff --git a/src/session/room/event.rs b/src/session/room/event.rs
index 6fd6e790..2ab260ef 100644
--- a/src/session/room/event.rs
+++ b/src/session/room/event.rs
@@ -66,7 +66,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "show-header",
                         "Show Header",
-                        "Whether this event should show a header or not. This does do nothing if this event 
doesn't have a header. ",
+                        "Whether this event should show a header. This does nothing if this event doesn’t 
have a header. ",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
@@ -147,7 +147,7 @@ glib::wrapper! {
 // TODO:
 // - [ ] implement operations for events: forward, reply, delete...
 
-/// This is the GObject represatation of a matrix room event
+/// This is the GObject representation of a matrix room event
 impl Event {
     pub fn new(event: &AnyRoomEvent, source: &String, sender: &User) -> Self {
         let event = BoxedAnyRoomEvent(event.to_owned());
diff --git a/src/session/room/item.rs b/src/session/room/item.rs
index baef85f8..08b4d69b 100644
--- a/src/session/room/item.rs
+++ b/src/session/room/item.rs
@@ -55,21 +55,21 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "selectable",
                         "Selectable",
-                        "Whether this item is selectable or not.",
+                        "Whether this item is selectable.",
                         false,
                         glib::ParamFlags::READABLE,
                     ),
                     glib::ParamSpec::new_boolean(
                         "show-header",
                         "Show Header",
-                        "Whether this item should show a header or not. This does do nothing if this event 
doesn't have a header. ",
+                        "Whether this item should show a header. This does do nothing if this event doesn’t 
have a header. ",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
                     glib::ParamSpec::new_boolean(
                         "can-hide-header",
                         "Can hide header",
-                        "Whether this item is allowed to hide it's header or not.",
+                        "Whether this item is allowed to hide its header.",
                         false,
                         glib::ParamFlags::READABLE,
                     ),
diff --git a/src/session/room/room_type.rs b/src/session/room/room_type.rs
index 8f8dd92b..ca80a07d 100644
--- a/src/session/room/room_type.rs
+++ b/src/session/room/room_type.rs
@@ -1,7 +1,7 @@
 use gettextrs::gettext;
 use gtk::glib;
 
-// TODO: do we also want the categorie `People` and a custom categorie support?
+// TODO: do we also want the category `People` and a custom category support?
 #[derive(Debug, Hash, Eq, PartialEq, Clone, Copy, glib::GEnum)]
 #[repr(u32)]
 #[genum(type_name = "RoomType")]
diff --git a/src/session/room/timeline.rs b/src/session/room/timeline.rs
index 4acc7c4e..9206dfea 100644
--- a/src/session/room/timeline.rs
+++ b/src/session/room/timeline.rs
@@ -18,11 +18,11 @@ mod imp {
     #[derive(Debug, Default)]
     pub struct Timeline {
         pub room: OnceCell<Room>,
-        /// A store to keep track of related events that arn't known
+        /// A store to keep track of related events that aren't known
         pub relates_to_events: RefCell<HashMap<EventId, Vec<EventId>>>,
-        /// All events Tilshown in the room history
+        /// All events shown in the room history
         pub list: RefCell<VecDeque<Item>>,
-        /// A Hashmap linking `EventId` to correspondenting `Event`
+        /// A Hashmap linking `EventId` to corresponding `Event`
         pub event_map: RefCell<HashMap<EventId, Event>>,
         /// Maps the temporary `EventId` of the pending Event to the real `EventId`
         pub pending_events: RefCell<HashMap<EventId, EventId>>,
@@ -50,7 +50,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "empty",
                         "Empty",
-                        "Whether the timeline is empty or not",
+                        "Whether the timeline is empty",
                         false,
                         glib::ParamFlags::READABLE,
                     ),
@@ -267,7 +267,7 @@ impl Timeline {
     }
 
     /// Append the new events
-    // TODO: This should be lazy, for isperation see: 
https://blogs.gnome.org/ebassi/documentation/lazy-loading/
+    // TODO: This should be lazy, for inspiration see: 
https://blogs.gnome.org/ebassi/documentation/lazy-loading/
     pub fn append<T: DeserializeOwned>(&self, batch: Vec<(AnyRoomEvent, Raw<T>)>) {
         let priv_ = imp::Timeline::from_instance(self);
 
@@ -279,7 +279,7 @@ impl Timeline {
         let index = {
             let index = {
                 let mut list = priv_.list.borrow_mut();
-                // Extened the size of the list so that rust doesn't need to realocate memory multiple times
+                // Extend the size of the list so that rust doesn't need to reallocate memory multiple times
                 list.reserve(batch.len());
                 list.len()
             };
@@ -319,7 +319,7 @@ impl Timeline {
         self.items_changed(index as u32, 0, added as u32);
     }
 
-    /// Append an event that wasn't yet fully send and received via a sync
+    /// Append an event that wasn't yet fully sent and received via a sync
     pub fn append_pending(&self, event: AnyRoomEvent) {
         let priv_ = imp::Timeline::from_instance(self);
 
@@ -368,7 +368,7 @@ impl Timeline {
         let mut added = batch.len();
 
         {
-            // Extened the size of the list so that rust doesn't need to realocate memory multiple times
+            // Extend the size of the list so that rust doesn't need to reallocate memory multiple times
             priv_.list.borrow_mut().reserve(added);
 
             for (event, raw) in batch {
diff --git a/src/session/sidebar/sidebar.rs b/src/session/sidebar/sidebar.rs
index d934e188..04eebb41 100644
--- a/src/session/sidebar/sidebar.rs
+++ b/src/session/sidebar/sidebar.rs
@@ -54,7 +54,7 @@ mod imp {
                     glib::ParamSpec::new_boolean(
                         "compact",
                         "Compact",
-                        "Wheter a compact view is used or not",
+                        "Whether a compact view is used",
                         false,
                         glib::ParamFlags::READWRITE,
                     ),
diff --git a/src/session/user.rs b/src/session/user.rs
index 1875ca92..3e75d374 100644
--- a/src/session/user.rs
+++ b/src/session/user.rs
@@ -114,7 +114,7 @@ glib::wrapper! {
     pub struct User(ObjectSubclass<imp::User>);
 }
 
-/// This is a `glib::Object` rapresentation of matrix users.
+/// This is a `glib::Object` representation of matrix users.
 impl User {
     pub fn new(session: &Session, user_id: &UserId) -> Self {
         glib::Object::new(&[("session", session), ("user-id", &user_id.to_string())])
diff --git a/src/utils.rs b/src/utils.rs
index fda2c333..6642b57e 100644
--- a/src/utils.rs
+++ b/src/utils.rs
@@ -1,4 +1,4 @@
-/// FIXME: This should be addressed in ruma direclty
+/// FIXME: This should be addressed in ruma directly
 #[macro_export]
 macro_rules! fn_event {
     ( $event:ident, $fun:ident ) => {
@@ -11,7 +11,7 @@ macro_rules! fn_event {
     };
 }
 
-/// FIXME: This should be addressed in ruma direclty
+/// FIXME: This should be addressed in ruma directly
 #[macro_export]
 macro_rules! event_from_sync_event {
     ( $event:ident, $room_id:ident) => {
@@ -35,7 +35,7 @@ macro_rules! event_from_sync_event {
 use crate::RUNTIME;
 use gtk::glib;
 use std::future::Future;
-/// Exexcute a future on a tokio runtime and spawn a future on the local thread to handle the result
+/// Execute a future on a tokio runtime and spawn a future on the local thread to handle the result
 pub fn do_async<
     R: Send + 'static,
     F1: Future<Output = R> + Send + 'static,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/session/room/room.rs b/src/session/room/room.rs
index be1c6cae..dfa47d44 100644
--- a/src/session/room/room.rs
+++ b/src/session/room/room.rs
@@ -55,7 +55,7 @@ mod imp {
         pub category: Cell<RoomType>,
         pub timeline: OnceCell<Timeline>,
         pub room_members: RefCell<HashMap<UserId, User>>,
         /// The user who send the invite to this room. This is only set when this room is an invitiation.
         pub inviter: RefCell<Option<User>>,
     }
 
@@ -94,7 +94,7 @@ mod imp {
                     glib::ParamSpec::new_object(
                         "inviter",
                         "Inviter",
-                        "The user who send the invite to this room, this is only set when this room 
rapresents an invite",
+                        "The user who sent the invite to this room, this is only set when this room 
represents an invite",
                         User::static_type(),
                         glib::ParamFlags::READABLE,
                     ),
@@ -295,7 +295,7 @@ impl Room {
         }
 
         if category == RoomType::Invited {
-            warn!("Rooms can't be moved to the invite Category");
+            warn!("Rooms can’t be moved to the invite Category");
             return;
         }
 
@@ -360,7 +360,7 @@ impl Room {
                 match result {
                         Ok(_) => {},
                         Err(error) => {
-                                error!("Couldn't set the room category: {}", error);
+                                error!("Couldn’t set the room category: {}", error);
                                 let error = Error::new(
                                         error,
                                         clone!(@weak obj => @default-return None, move |_| {
@@ -467,7 +467,7 @@ impl Room {
                 // FIXME: We should retry to if the request failed
                 match display_name {
                         Ok(display_name) => obj.set_display_name(Some(display_name)),
-                        Err(error) => error!("Couldn't fetch display name: {}", error),
+                        Err(error) => error!("Couldn’t fetch display name: {}", error),
                 };
             }),
         );
@@ -504,7 +504,7 @@ impl Room {
 
     /// Handle stripped state events.
     ///
-    /// Events passed to this function arn't added to the timeline.
+    /// Events passed to this function aren't added to the timeline.
     pub fn handle_invite_events(&self, events: Vec<AnyStrippedStateEvent>) {
         let priv_ = imp::Room::from_instance(self);
         let invite_event = events
@@ -554,7 +554,7 @@ impl Room {
                     self.avatar().set_url(event.content.url.to_owned());
                 }
                 AnyRoomEvent::State(AnyStateEvent::RoomName(_)) => {
-                    // FIXME: this doesn't take in account changes in the calculated name
+                    // FIXME: this doesn't take into account changes in the calculated name
                     self.load_display_name()
                 }
                 AnyRoomEvent::State(AnyStateEvent::RoomTopic(_)) => {
@@ -567,7 +567,7 @@ impl Room {
         priv_.timeline.get().unwrap().append(batch);
     }
 
-    /// Add an initial set of members needed to diplay room events
+    /// Add an initial set of members needed to display room events
     ///
     /// The `Timeline` makes sure to update the members when a member state event arrives
     fn add_members(&self, members: Vec<RoomMember>) {
@@ -602,14 +602,14 @@ impl Room {
                 // FIXME: We should retry to load the room members if the request failed
                 match members {
                         Ok(members) => obj.add_members(members),
-                        Err(error) => error!("Couldn't load room members: {}", error),
+                        Err(error) => error!("Couldn’t load room members: {}", error),
                 };
             }),
         );
     }
 
     pub fn load_previous_events(&self) {
-        warn!("Loading previous evetns is not yet implemented");
+        warn!("Loading previous events is not yet implemented");
         /*
         let matrix_room = priv_.matrix_room.get().unwrap().clone();
         do_async(
@@ -618,7 +618,7 @@ impl Room {
                 // FIXME: We should retry to load the room members if the request failed
                 match events {
                         Ok(events) => obj.prepend(events),
-                        Err(error) => error!("Couldn't load room members: {}", error),
+                        Err(error) => error!("Couldn’t load room members: {}", error),
                 };
             }),
         );
@@ -680,7 +680,7 @@ impl Room {
                                     let priv_ = imp::Room::from_instance(&obj);
                                     priv_.timeline.get().unwrap().set_event_id_for_pending(pending_id, 
result.event_id)
                             },
-                            Err(error) => error!("Couldn't send message: {}", error),
+                            Err(error) => error!("Couldn’t send message: {}", error),
                     };
                 }),
             );
@@ -712,7 +712,7 @@ impl Room {
                 }
             }
         } else {
-            error!("Can't accept invite, because this room isn't an invited room");
+            error!("Can’t accept invite, because this room isn’t an invited room");
             Ok(())
         }
     }
@@ -742,7 +742,7 @@ impl Room {
                 }
             }
         } else {
-            error!("Can't reject invite, because this room isn't an invited room");
+            error!("Can’t reject invite, because this room isn’t an invited room");
             Ok(())
         }
     }
@@ -761,7 +761,7 @@ impl Room {
                     if let Ok(event) = raw_event.event.deserialize() {
                         Some((event, raw_event.event))
                     } else {
-                        error!("Couldn't deserialize event: {:?}", raw_event);
+                        error!("Couldn’t deserialize event: {:?}", raw_event);
                         None
                     }
                 })
@@ -793,7 +793,7 @@ impl Room {
                     if let Ok(event) = raw_event.event.deserialize() {
                         Some((event, raw_event.event))
                     } else {
-                        error!("Couldn't deserialize event: {:?}", raw_event);
+                        error!("Couldn’t deserialize event: {:?}", raw_event);
                         None
                     }
                 })
@@ -814,7 +814,7 @@ impl Room {
                     if let Ok(event) = event.deserialize() {
                         Some(event)
                     } else {
-                        error!("Couldn't deserialize event: {:?}", event);
+                        error!("Couldn’t deserialize event: {:?}", event);
                         None
                     }
                 })
@@ -55,7 +55,7 @@ mod imp {
         pub timeline: OnceCell<Timeline>,
         pub room_members: RefCell<HashMap<UserId, User>>,
-        /// The user who send the invite to this room. This is only set when this room is an invitiation.
+        /// The user who sent the invite to this room. This is only set when this room is an invitiation.
         pub inviter: RefCell<Option<User>>,
     }